@@ -1,9 +1,9 @@
 """
-Main code used to evaluate DeepLC performance
+Transfer learning with DeepLC
 """
 
-__author__ = ["Robbin Bouwmeester", "Ralf Gabriels"]
-__credits__ = ["Robbin Bouwmeester", "Ralf Gabriels", "Prof. Lennart Martens", "Sven Degroeve"]
+__author__ = ["Robbin Bouwmeester", "Arthur Declercq", "Ralf Gabriels"]
+__credits__ = ["Robbin Bouwmeester", "Ralf Gabriels", "Arthur Declercq", "Prof. Lennart Martens", "Prof. Sven Degroeve"]
 __license__ = "Apache License, Version 2.0"
 __maintainer__ = ["Robbin Bouwmeester", "Ralf Gabriels"]
 __email__ = ["Robbin.Bouwmeester@ugent.be", "Ralf.Gabriels@ugent.be"]
@@ -12,6 +12,8 @@ from tensorflow.compat.v1 import ConfigProto
 from tensorflow.compat.v1 import InteractiveSession
 from tensorflow.keras.callbacks import ModelCheckpoint
 from tensorflow.keras.models import load_model
+import h5py
+import pandas as pd
 
 import sys
 from multiprocessing import freeze_support
@@ -20,6 +22,8 @@ import importlib.resources
 from tensorflow.keras.layers import ReLU
 import importlib
 
+import tempfile
+
 try:
     from gooey import Gooey, local_resource_path
     from gooey import GooeyParser
@@ -45,6 +49,12 @@ import sys
 from argparse import HelpFormatter
 import os
 
+from psm_utils.io.peptide_record import peprec_to_proforma
+from psm_utils.psm import PSM
+from psm_utils.psm_list import PSMList
+from psm_utils.io import read_file
+from psm_utils.io import write_file
+
 config = ConfigProto()
 config.gpu_options.allow_growth = True
 session = InteractiveSession(config=config)
@@ -166,7 +176,7 @@ def retrain(
         plot_results=False,
         write_csv_results=False,
         freeze_after_concat=0,
-        outpath="./",
+        outpath=None,
         a_blocks=[3],
         a_kernel=[2,4,8],
         a_max_pool=[2],
@@ -179,9 +189,13 @@ def retrain(
         b_stride=[1],
         global_neurons=[16],
         global_num_dens=[3],
-        regularizer_val=[0.0000025]
+        regularizer_val=[0.0000025],
+        remove_repeats=True,
     ):
 
+    if not outpath:
+        outpath = tempfile.mkdtemp()
+
     params = list(itertools.product(*[a_blocks,
                                         a_kernel,
                                         a_max_pool,
@@ -207,12 +221,45 @@ def retrain(
     if type(datasets) == str:
         datasets = [datasets]
 
-    for dataset_name in datasets:
-        df = cnn_functions.read_infile(dataset_name)
-        df = cnn_functions.get_feat_df(df,costum_modification_file=costum_modification_file)
+    # catch above list creation for PSM list
+    if type(datasets) == list:
+        datasets = dict([(".".join(d.split(".")[:-1]),d) for d in datasets])
+        for dataset_name, file_name in datasets.items():
+            list_of_psms = []
+            datasets[dataset_name] = pd.read_csv(file_name)
+            datasets[dataset_name].fillna("",inplace=True)
+            datasets[dataset_name].rename(columns = {'observed_retention_time':'tr', 'peptide':'seq'}, inplace = True)
+            
+            if remove_repeats:
+                datasets[dataset_name].sort_values("tr",inplace=True)
+                datasets[dataset_name].drop_duplicates(["seq","modifications"],keep="first",inplace=True)
 
-        if use_correction_factor: correction_factor = (df["tr"].max())/10.0
-        else: correction_factor = 1.0
+            for seq,mod,id,tr in zip(datasets[dataset_name]["seq"],datasets[dataset_name]["modifications"],datasets[dataset_name].index,datasets[dataset_name]["tr"]):
+                list_of_psms.append(PSM(peptidoform=peprec_to_proforma(seq,mod),spectrum_id=id,retention_time=tr))
+            psm_list = PSMList(psm_list=list_of_psms)
+
+            datasets[dataset_name] = psm_list
+    elif remove_repeats and type(datasets) == dict:
+        for dataset_name,psm_list in datasets.items():
+            psm_list_with_tr = [(psm,psm.retention_time,psm.peptidoform) for psm in psm_list]
+            psm_list_with_tr = sorted(psm_list_with_tr,key=lambda l:l[1])
+
+            prev_analyzed = set()
+            list_of_psms = []
+            
+            for psm,tr,proforma_seq in psm_list_with_tr:
+                if proforma_seq not in prev_analyzed:
+                    list_of_psms.append(psm)
+                    prev_analyzed.add(proforma_seq)
+                else:
+                    continue
+            psm_list = PSMList(psm_list=list_of_psms)
+            datasets[dataset_name] = psm_list
+
+    for dataset_name,psm_list in datasets.items():
+        df = cnn_functions.get_feat_df(psm_list=psm_list,costum_modification_file=costum_modification_file)
+
+        correction_factor = 1.0
 
         df_train,df_test = cnn_functions.train_test(df,ratio_train=ratio_test)
         df_train,df_valid = cnn_functions.train_test(df_train,ratio_train=ratio_valid)
@@ -241,8 +288,7 @@ def retrain(
 
             if len(matched_mod) > 0:
                 model = load_model(
-                                matched_mod,
-                                custom_objects={'<lambda>': lrelu}
+                                h5py.File(matched_mod), custom_objects={"<lambda>": lrelu}
                             )
 
                 if freeze_layers:
@@ -293,8 +339,7 @@ def retrain(
                                     callbacks=[mcp_save],
                                     shuffle=True)
 
-            mods_optimized.append(load_model(mod_name,
-                                            custom_objects = {'<lambda>': lrelu}))
+            mods_optimized.append(load_model(h5py.File(mod_name), custom_objects={"<lambda>": lrelu}))
 
             mods_loc_optimized.append(mod_name)
         
@@ -369,17 +414,17 @@ def retrain(
     if len(mods_loc_optimized_all) == 1:
         return mods_loc_optimized_all[0]
     else:
-        return mods_loc_optimized_all[0]
+        return mods_loc_optimized_all
 
-@Gooey(
-    program_name="DeepLC re-tR-ainer",
-    default_size=(720, 790),
-    monospace_display=True
-)
+#@Gooey(
+#    program_name="DeepLC re-tR-ainer",
+#    default_size=(720, 790),
+#    monospace_display=True
+#)
 def main():
     argu = parse_arguments()
     retrain(**vars(argu))
     
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    Gooey(main)()
